from setuptools import setup

setup(name='gauss_bino_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['gauss_bino_distributions'],
      author='Prasenjit Das',
      zip_safe=False)
